import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy, ViewEncapsulation, Input, EventEmitter, forwardRef, ViewChild, Output, NgModule } from '@angular/core';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { NG_VALUE_ACCESSOR } from '@angular/forms';

class BbiCheckboxGroup {
    constructor(_changeDetectorRef) {
        this._changeDetectorRef = _changeDetectorRef;
        // Inputs.
        this.label = null; // TODO(Stan): Add template possibilities here.
        this._grouped = false;
        this._required = false;
    }
    // Grouped.
    get grouped() { return this._grouped; }
    set grouped(value) {
        const newValue = coerceBooleanProperty(value);
        if (newValue !== this.grouped) {
            this._grouped = newValue;
            this._changeDetectorRef.markForCheck();
        }
    }
    // Required.
    get required() { return this._required; }
    set required(value) {
        const newValue = coerceBooleanProperty(value);
        if (newValue !== this.required) {
            this._required = newValue;
            this._changeDetectorRef.markForCheck();
        }
    }
}
BbiCheckboxGroup.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: BbiCheckboxGroup, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
BbiCheckboxGroup.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.6", type: BbiCheckboxGroup, selector: "bbi-checkbox-group", inputs: { label: "label", grouped: "grouped", required: "required" }, host: { properties: { "class.grouped": "grouped", "class.required": "required" }, classAttribute: "bbi-checkbox-group" }, ngImport: i0, template: "<label *ngIf=\"label as label\"\n       class=\"bbi-checkbox-group-label\">\n    {{ label }}\n</label>\n\n<div class=\"bbi-checkbox-group-items\">\n    <ng-content select=\"bbi-checkbox\"></ng-content>\n</div>\n", styles: [".bbi-checkbox-group{display:block}.bbi-checkbox-group.grouped{margin-bottom:20px}.bbi-checkbox-group.required>.bbi-checkbox-group-label:after{content:\"*\";color:#c23934;font-size:12px;line-height:1.5}.bbi-checkbox-group-label{border:0;padding:0;line-height:1.33;margin-bottom:4px;font-family:inherit;display:inline-block;box-sizing:border-box;vertical-align:initial;color:var(--checkbox-group-label-color, #525252);font-size:var(--checkbox-group-label-size, 14px);font-weight:var(--checkbox-group-label-weight, 400)}.bbi-checkbox-group-items{display:flex;flex-direction:column}.bbi-checkbox-group-items:not(:empty){margin-bottom:-4px}.bbi-checkbox-group-items>*{margin-bottom:4px}@media only screen and (min-width: 768px){.bbi-checkbox-group:not(.vertical)>.bbi-checkbox-group-items{flex-wrap:wrap;flex-direction:row}.bbi-checkbox-group:not(.vertical)>.bbi-checkbox-group-items>*:not(:last-child){margin-right:10px}}\n"], directives: [{ type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: BbiCheckboxGroup, decorators: [{
            type: Component,
            args: [{ selector: 'bbi-checkbox-group', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: {
                        'class': 'bbi-checkbox-group',
                        '[class.grouped]': 'grouped',
                        '[class.required]': 'required'
                    }, preserveWhitespaces: false, template: "<label *ngIf=\"label as label\"\n       class=\"bbi-checkbox-group-label\">\n    {{ label }}\n</label>\n\n<div class=\"bbi-checkbox-group-items\">\n    <ng-content select=\"bbi-checkbox\"></ng-content>\n</div>\n", styles: [".bbi-checkbox-group{display:block}.bbi-checkbox-group.grouped{margin-bottom:20px}.bbi-checkbox-group.required>.bbi-checkbox-group-label:after{content:\"*\";color:#c23934;font-size:12px;line-height:1.5}.bbi-checkbox-group-label{border:0;padding:0;line-height:1.33;margin-bottom:4px;font-family:inherit;display:inline-block;box-sizing:border-box;vertical-align:initial;color:var(--checkbox-group-label-color, #525252);font-size:var(--checkbox-group-label-size, 14px);font-weight:var(--checkbox-group-label-weight, 400)}.bbi-checkbox-group-items{display:flex;flex-direction:column}.bbi-checkbox-group-items:not(:empty){margin-bottom:-4px}.bbi-checkbox-group-items>*{margin-bottom:4px}@media only screen and (min-width: 768px){.bbi-checkbox-group:not(.vertical)>.bbi-checkbox-group-items{flex-wrap:wrap;flex-direction:row}.bbi-checkbox-group:not(.vertical)>.bbi-checkbox-group-items>*:not(:last-child){margin-right:10px}}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }]; }, propDecorators: { label: [{
                type: Input
            }], grouped: [{
                type: Input
            }], required: [{
                type: Input
            }] } });

let nextUniqueId = 0;
class BbiCheckbox {
    constructor(_renderer, _changeDetectorRef) {
        this._renderer = _renderer;
        this._changeDetectorRef = _changeDetectorRef;
        // Readonly data.
        this.labelId = `bbi-checkbox-${nextUniqueId++}`;
        // Outputs.
        this.checkedChange = new EventEmitter();
        this.indeterminateChange = new EventEmitter();
        this._checked = false;
        this._disabled = false;
        this._grouped = false;
        this._indeterminate = false;
        this._required = false;
        // Methods.
        this.onChange = () => ({});
        this.onTouched = () => ({});
    }
    // Checked.
    get checked() { return this._checked; }
    set checked(value) {
        const newValue = coerceBooleanProperty(value);
        if (newValue !== this.checked) {
            this._checked = newValue;
            this._changeDetectorRef.markForCheck();
        }
    }
    // Disabled.
    get disabled() { return this._disabled; }
    set disabled(value) {
        const newValue = coerceBooleanProperty(value);
        if (newValue !== this.disabled) {
            this._disabled = newValue;
            this._changeDetectorRef.markForCheck();
        }
    }
    // Grouped.
    get grouped() { return this._grouped; }
    set grouped(value) {
        const newValue = coerceBooleanProperty(value);
        if (newValue !== this.grouped) {
            this._grouped = newValue;
            this._changeDetectorRef.markForCheck();
        }
    }
    // Indeterminate.
    get indeterminate() { return this._indeterminate; }
    set indeterminate(value) {
        this._indeterminate = coerceBooleanProperty(value);
        this.syncField('indeterminate', this._indeterminate);
    }
    // Required.
    get required() { return this._required; }
    set required(value) {
        const newValue = coerceBooleanProperty(value);
        if (newValue !== this.required) {
            this._required = newValue;
            this._changeDetectorRef.markForCheck();
        }
    }
    ngAfterViewInit() {
        this.syncField('indeterminate', this._indeterminate);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    writeValue(newValue) {
        this.checked = !!newValue;
    }
    toggle() {
        this.checked = !this.checked;
    }
    onClickEvent(event) {
        event.stopPropagation();
        if (this.disabled) {
            return;
        }
        // When user manually click on the checkbox, `indeterminate` is set to false.
        if (this.indeterminate) {
            Promise.resolve().then(() => {
                this._indeterminate = false;
                this.indeterminateChange.emit(this._indeterminate);
            });
        }
        this.toggle();
        // Emit our custom change event if the native input emitted one.
        // It is important to only emit it, if the native input triggered one, because
        // we don't want to trigger a change event, when the `checked` variable changes for example.
        this.emitChangeEvent();
    }
    onChangeEvent(event) {
        // We always have to stop propagation on the change event.
        // Otherwise the change event, from the input element, will bubble up and
        // emit its event object to the `change` output.
        event.stopPropagation();
    }
    emitChangeEvent() {
        var _a;
        (_a = this.onChange) === null || _a === void 0 ? void 0 : _a.call(this, this.checked);
        this.checkedChange.emit(this.checked);
        this.syncField('checked', this.checked);
    }
    syncField(field, value) {
        var _a;
        const element = (_a = this.inputElementRef) === null || _a === void 0 ? void 0 : _a.nativeElement;
        if (!element) {
            return;
        }
        this._renderer.setProperty(element, field, value);
    }
}
BbiCheckbox.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: BbiCheckbox, deps: [{ token: i0.Renderer2 }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
BbiCheckbox.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.6", type: BbiCheckbox, selector: "bbi-checkbox", inputs: { checked: "checked", disabled: "disabled", grouped: "grouped", indeterminate: "indeterminate", required: "required" }, outputs: { checkedChange: "checkedChange", indeterminateChange: "indeterminateChange" }, host: { properties: { "class.grouped": "grouped", "class.indeterminate": "indeterminate", "class.required": "required" }, classAttribute: "bbi-checkbox" }, providers: [
        { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => BbiCheckbox), multi: true }
    ], viewQueries: [{ propertyName: "inputElementRef", first: true, predicate: ["input"], descendants: true, static: true }], ngImport: i0, template: "<input #input\n       [id]=\"labelId\"\n       [disabled]=\"disabled\"\n       [checked]=\"checked\"\n       (change)=\"onChangeEvent($event)\"\n       (click)=\"onClickEvent($event)\"\n       (blur)=\"onTouched()\"\n       class=\"bbi-checkbox-input\"\n       type=\"checkbox\">\n<label [attr.for]=\"labelId\"\n       class=\"bbi-checkbox-label\">\n    <span class=\"bbi-checkbox-text\"><ng-content></ng-content></span>\n</label>\n", styles: [".bbi-checkbox{display:block}.bbi-checkbox.grouped{margin-bottom:20px}.bbi-checkbox.required>.bbi-checkbox-label>.bbi-checkbox-text:after{content:\"*\";color:#c23934;font-size:12px;line-height:1.5;margin-left:3px}.bbi-checkbox-input{border:0;width:1px;padding:0;height:1px;margin:-1px;overflow:hidden;position:absolute;visibility:inherit;white-space:nowrap;clip:rect(0,0,0,0)}.bbi-checkbox-input:checked+.bbi-checkbox-label:before,.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:before{border:1px solid var(--checkbox-accent-color, #1565c0);background-color:var(--checkbox-accent-color, #1565c0)}.bbi-checkbox-input:checked+.bbi-checkbox-label:after,.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:after{opacity:1;transform:scale(1) rotate(-45deg)}.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:after{top:-1px;left:5px;width:10px;transform:scale(1) rotate(0);border-left:0 solid var(--checkbox-check-color, white);border-bottom:2px solid var(--checkbox-check-color, white)}.bbi-checkbox-input:focus+.bbi-checkbox-label:before{outline-color:var(--checkbox-accent-color, #1565c0)}.bbi-checkbox-input:disabled+.bbi-checkbox-label{cursor:not-allowed;color:var(--checkbox-disabled-color, #c6c6c6)}.bbi-checkbox-input:disabled+.bbi-checkbox-label:before{border-color:var(--checkbox-disabled-color, #c6c6c6)}.bbi-checkbox-input:disabled+.bbi-checkbox-label>.bbi-checkbox-text{color:var(--checkbox-disabled-color, #c6c6c6)}.bbi-checkbox-input:checked:disabled+.bbi-checkbox-label:before,.bbi-checkbox-input:indeterminate:disabled+.bbi-checkbox-label:before{background-color:var(--checkbox-disabled-color, #c6c6c6)}.bbi-checkbox-label{border:0;margin:0;display:flex;cursor:pointer;font-size:16px;font-weight:400;line-height:1.28;-webkit-user-select:none;user-select:none;position:relative;padding-left:20px;font-family:inherit;vertical-align:initial}.bbi-checkbox-label:before{left:0;width:20px;content:\"\";height:20px;position:absolute;border-radius:4px;outline-offset:1px;background-color:initial;outline:2px solid transparent;border:1px solid var(--checkbox-border-color, #111111);transition:outline-color .2s cubic-bezier(0,0,.2,1),background-color .18s cubic-bezier(0,0,.2,1),border-color .18s cubic-bezier(0,0,.2,1)}.bbi-checkbox-label:after{left:4px;opacity:0;width:12px;height:6px;content:\"\";margin-top:6px;background:none;position:absolute;transform-origin:center;transform:scale(.85) rotate(-60deg);border-left:2px solid var(--checkbox-check-color, white);border-bottom:2px solid var(--checkbox-check-color, white);transition:opacity .12s cubic-bezier(0,0,.2,1),transform .18s cubic-bezier(0,0,.2,1)}.bbi-checkbox-text{padding-left:6px;color:var(--checkbox-label-color, #111111)}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: BbiCheckbox, decorators: [{
            type: Component,
            args: [{ selector: 'bbi-checkbox', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, providers: [
                        { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => BbiCheckbox), multi: true }
                    ], host: {
                        'class': 'bbi-checkbox',
                        '[class.grouped]': 'grouped',
                        '[class.indeterminate]': 'indeterminate',
                        '[class.required]': 'required'
                    }, preserveWhitespaces: false, template: "<input #input\n       [id]=\"labelId\"\n       [disabled]=\"disabled\"\n       [checked]=\"checked\"\n       (change)=\"onChangeEvent($event)\"\n       (click)=\"onClickEvent($event)\"\n       (blur)=\"onTouched()\"\n       class=\"bbi-checkbox-input\"\n       type=\"checkbox\">\n<label [attr.for]=\"labelId\"\n       class=\"bbi-checkbox-label\">\n    <span class=\"bbi-checkbox-text\"><ng-content></ng-content></span>\n</label>\n", styles: [".bbi-checkbox{display:block}.bbi-checkbox.grouped{margin-bottom:20px}.bbi-checkbox.required>.bbi-checkbox-label>.bbi-checkbox-text:after{content:\"*\";color:#c23934;font-size:12px;line-height:1.5;margin-left:3px}.bbi-checkbox-input{border:0;width:1px;padding:0;height:1px;margin:-1px;overflow:hidden;position:absolute;visibility:inherit;white-space:nowrap;clip:rect(0,0,0,0)}.bbi-checkbox-input:checked+.bbi-checkbox-label:before,.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:before{border:1px solid var(--checkbox-accent-color, #1565c0);background-color:var(--checkbox-accent-color, #1565c0)}.bbi-checkbox-input:checked+.bbi-checkbox-label:after,.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:after{opacity:1;transform:scale(1) rotate(-45deg)}.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:after{top:-1px;left:5px;width:10px;transform:scale(1) rotate(0);border-left:0 solid var(--checkbox-check-color, white);border-bottom:2px solid var(--checkbox-check-color, white)}.bbi-checkbox-input:focus+.bbi-checkbox-label:before{outline-color:var(--checkbox-accent-color, #1565c0)}.bbi-checkbox-input:disabled+.bbi-checkbox-label{cursor:not-allowed;color:var(--checkbox-disabled-color, #c6c6c6)}.bbi-checkbox-input:disabled+.bbi-checkbox-label:before{border-color:var(--checkbox-disabled-color, #c6c6c6)}.bbi-checkbox-input:disabled+.bbi-checkbox-label>.bbi-checkbox-text{color:var(--checkbox-disabled-color, #c6c6c6)}.bbi-checkbox-input:checked:disabled+.bbi-checkbox-label:before,.bbi-checkbox-input:indeterminate:disabled+.bbi-checkbox-label:before{background-color:var(--checkbox-disabled-color, #c6c6c6)}.bbi-checkbox-label{border:0;margin:0;display:flex;cursor:pointer;font-size:16px;font-weight:400;line-height:1.28;-webkit-user-select:none;user-select:none;position:relative;padding-left:20px;font-family:inherit;vertical-align:initial}.bbi-checkbox-label:before{left:0;width:20px;content:\"\";height:20px;position:absolute;border-radius:4px;outline-offset:1px;background-color:initial;outline:2px solid transparent;border:1px solid var(--checkbox-border-color, #111111);transition:outline-color .2s cubic-bezier(0,0,.2,1),background-color .18s cubic-bezier(0,0,.2,1),border-color .18s cubic-bezier(0,0,.2,1)}.bbi-checkbox-label:after{left:4px;opacity:0;width:12px;height:6px;content:\"\";margin-top:6px;background:none;position:absolute;transform-origin:center;transform:scale(.85) rotate(-60deg);border-left:2px solid var(--checkbox-check-color, white);border-bottom:2px solid var(--checkbox-check-color, white);transition:opacity .12s cubic-bezier(0,0,.2,1),transform .18s cubic-bezier(0,0,.2,1)}.bbi-checkbox-text{padding-left:6px;color:var(--checkbox-label-color, #111111)}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.Renderer2 }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { inputElementRef: [{
                type: ViewChild,
                args: ['input', { static: true }]
            }], checkedChange: [{
                type: Output
            }], indeterminateChange: [{
                type: Output
            }], checked: [{
                type: Input
            }], disabled: [{
                type: Input
            }], grouped: [{
                type: Input
            }], indeterminate: [{
                type: Input
            }], required: [{
                type: Input
            }] } });

class CheckboxModule {
}
CheckboxModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: CheckboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CheckboxModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: CheckboxModule, declarations: [BbiCheckbox, BbiCheckboxGroup], imports: [CommonModule], exports: [BbiCheckbox, BbiCheckboxGroup] });
CheckboxModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: CheckboxModule, imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: CheckboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [BbiCheckbox, BbiCheckboxGroup],
                    exports: [BbiCheckbox, BbiCheckboxGroup]
                }]
        }] });

class ControlsModule {
}
ControlsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: ControlsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ControlsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: ControlsModule, imports: [CheckboxModule], exports: [CheckboxModule] });
ControlsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: ControlsModule, imports: [[CheckboxModule], CheckboxModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.6", ngImport: i0, type: ControlsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CheckboxModule],
                    exports: [CheckboxModule]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BbiCheckbox, BbiCheckboxGroup, CheckboxModule, ControlsModule };
//# sourceMappingURL=bravobit-bb-foundation-controls.mjs.map
